--- a/bgpd/bgp_attr.c
+++ b/bgpd/bgp_attr.c
@@ -1240,10 +1240,17 @@
 	}
 
 	/* Only relax error handling for eBGP peers */
-	if (peer->sort != BGP_PEER_EBGP) {
-		bgp_notify_send_with_data(peer, BGP_NOTIFY_UPDATE_ERR, subcode,
-					  notify_datap, length);
-		return BGP_ATTR_PARSE_ERROR;
+	switch (subcode) {
+	/* Except for AS0 */
+	case BGP_NOTIFY_UPDATE_MAL_AS_PATH_ZERO:
+		subcode = BGP_NOTIFY_UPDATE_MAL_AS_PATH;
+		break;
+	default:
+		if (peer->sort != BGP_PEER_EBGP) {
+			bgp_notify_send_with_data(peer, BGP_NOTIFY_UPDATE_ERR, subcode,
+						  notify_datap, length);
+			return BGP_ATTR_PARSE_ERROR;
+		}
 	}
 
 	/* Adjust the stream getp to the end of the attribute, in case we can
@@ -1493,7 +1500,7 @@
 			EC_BGP_ATTR_MAL_AS_PATH,
 			"Malformed AS path, AS number is 0 in the path from %s",
 			peer->host);
-		return bgp_attr_malformed(args, BGP_NOTIFY_UPDATE_MAL_AS_PATH,
+		return bgp_attr_malformed(args, BGP_NOTIFY_UPDATE_MAL_AS_PATH_ZERO,
 					  0);
 	}
 
@@ -1574,7 +1581,7 @@
 			EC_BGP_ATTR_MAL_AS_PATH,
 			"Malformed AS path, AS number is 0 in the path from %s",
 			peer->host);
-		return bgp_attr_malformed(args, BGP_NOTIFY_UPDATE_MAL_AS_PATH,
+		return bgp_attr_malformed(args, BGP_NOTIFY_UPDATE_MAL_AS_PATH_ZERO,
 					  0);
 	}
 
--- a/bgpd/bgpd.h
+++ b/bgpd/bgpd.h
@@ -1728,6 +1728,7 @@
 #define BGP_NOTIFY_UPDATE_OPT_ATTR_ERR           9
 #define BGP_NOTIFY_UPDATE_INVAL_NETWORK         10
 #define BGP_NOTIFY_UPDATE_MAL_AS_PATH           11
+#define BGP_NOTIFY_UPDATE_MAL_AS_PATH_ZERO      12
 
 /* BGP_NOTIFY_CEASE sub codes (RFC 4486).  */
 #define BGP_NOTIFY_CEASE_MAX_PREFIX              1
